altair interactivity https://www.youtube.com/watch?v=x-iU2UwgVf0
folium = altair + leaflet http://python-visualization.github.io/folium/index.html


- panel https://towardsdatascience.com/how-to-build-a-time-series-dashboard-in-python-with-panel-altair-and-a-jupyter-notebook-c0ed40f02289
- holoviz https://holoviz.org/
